import { Icon, Image, Toast, Uploader } from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'
import ColCropper from '../col-cropper'
import { useCustomFieldValue } from '@vant/use'
import { postMessage } from '@/helpers/native-message'

import iconUploader from '@common/images/icon_uploader.png'
import request from '@/helpers/request'

export default defineComponent({
  name: 'col-upload',
  props: {
    modelValue: String,
    tips: {
      type: String,
      default: '点击上传'
    },
    deletable: {
      type: Boolean,
      default: true
    },
    native: {
      // 是否原生上传
      type: Boolean,
      default: false
    },
    cropper: {
      // 是否进行裁切
      type: Boolean,
      default: false
    },
    options: {
      // 裁切需要参数
      type: Object,
      default: {}
    },
    uploadSize: {
      // 上传图片大小
      type: Number,
      default: 5
    },
    onUploadChange: {
      type: Function,
      default: (url: string) => {}
    }
  },
  methods: {
    nativeUpload() {
      postMessage(
        { api: 'chooseFile', content: { type: 'img', max: 1 } },
        (res: any) => {
          this.$emit('update:modelValue', res.fileUrl)
        }
      )
    },
    beforeRead(file: any) {
      const isLt2M = file.size / 1024 / 1024 < this.uploadSize
      if (!isLt2M) {
        Toast(`上传文件大小不能超过 ${this.uploadSize}MB`)
        return false
      }
      return true
    },
    beforeDelete(file: any, detail: { index: any }) {
      // this.dataModel.splice(detail.index, 1)
      return true
    },
    async afterRead(file: any, detail: any) {
      try {
        file.status = 'uploading'
        file.message = '上传中...'
        let formData = new FormData()
        formData.append('file', file.file)
        let res = await request.post('/api-teacher/uploadFile', {
          data: formData
        })
        this.$emit('update:modelValue', res.data.url)
        this.onUploadChange(res.data.url)
      } catch (error) {
        //
      }
    },
    onClose(e: any) {
      this.$emit('update:modelValue', null)
      this.onUploadChange()
      e.stopPropagation()
    },
    async getFile(file: any) {
      // 上传文件
      try {
        let formData = new FormData()
        formData.append('file', file)
        let res = await request.post('/api-teacher/uploadFile', {
          data: formData
        })
        this.$emit('update:modelValue', res.data.url)
        this.onUploadChange(res.data.url)
      } catch {
        //
      }
    }
  },
  render() {
    useCustomFieldValue(() => this.modelValue)
    return (
      <div class={styles['uploader-section']}>
        {this.modelValue && this.deletable ? (
          <Icon
            name="cross"
            onClick={this.onClose}
            class={styles['img-close']}
          />
        ) : null}
        {this.cropper && !this.native ? (
          <div class={styles['col-uploader']}>
            {this.modelValue ? (
              <Image
                fit="cover"
                position="center"
                class={styles.uploadImg}
                src={this.modelValue}
              />
            ) : (
              <div class={styles.uploader}>
                <Icon name={iconUploader} size="32" />
                <p class={styles.uploaderText}>{this.tips}</p>
              </div>
            )}
            <ColCropper option={this.options} getFile={this.getFile} />
          </div>
        ) : this.native ? (
          <div
            style={{
              display: 'flex',
              alignItems: 'center',
              justifyContent: 'center',
              height: '100%'
            }}
            onClick={this.nativeUpload}
          >
            {this.modelValue ? (
              <Image
                fit="cover"
                position="center"
                class={styles.uploadImg}
                src={this.modelValue}
              />
            ) : (
              <div class={styles.uploader}>
                <Icon name={iconUploader} size="32" />
                <p class={styles.uploaderText}>{this.tips}</p>
              </div>
            )}
          </div>
        ) : (
          <Uploader
            afterRead={this.afterRead}
            beforeRead={this.beforeRead}
            beforeDelete={this.beforeDelete}
            v-slots={{
              default: () =>
                this.modelValue ? (
                  <Image
                    fit="cover"
                    position="center"
                    class={styles.uploadImg}
                    src={this.modelValue}
                  />
                ) : (
                  <div class={styles.uploader}>
                    <Icon name={iconUploader} size="32" />
                    <p class={styles.uploaderText}>{this.tips}</p>
                  </div>
                )
            }}
          />
        )}
      </div>
    )
  }
})
