import Auth from '@/teacher/layout/auth'
import { router, rootRouter } from './routes-common'

type metaType = {
  isRegister: boolean
}

export default [
  {
    path: '/',
    component: Auth,
    children: [
      ...router,
      {
        path: '/login',
        name: 'login',
        component: () => import('@/teacher/layout/login'),
        meta: {
          isRegister: false
        } as metaType
      },
      {
        path: '/home',
        name: 'home',
        component: () => import('@/teacher/home/index')
      },
      {
        path: '/teacherCert',
        name: 'teacherCert',
        component: () => import('@/teacher/teacher-cert/index'),
        meta: {
          title: '老师认证'
        }
      },
      {
        path: '/music-upload',
        component: () => import('@/teacher/music/upload'),
        meta: {
          title: '上传曲谱'
        }
      },
      {
        path: '/music-list',
        component: () => import('@/teacher/music/list/switch'),
        meta: {
          title: '曲谱列表'
        }
      },
      {
        path: '/openLive',
        name: 'openLive',
        component: () => import('@/teacher/open-live/index'),
        meta: {
          title: '开通直播'
        }
      },
      {
        path: '/liveDetail',
        name: 'liveDetail',
        component: () => import('@/teacher/live-class/live-detail'),
        meta: {
          title: '直播课详情'
        }
      },
      {
        path: '/musicCert',
        name: 'musicCert',
        component: () => import('@/teacher/music-cert/index'),
        meta: {
          title: '音乐人认证'
        }
      },
      {
        path: '/videoCreate',
        name: 'videoCreate',
        component: () => import('@/teacher/video-class/create'),
        meta: {
          title: '创建视频课'
        }
      },
      {
        path: '/videoDetail',
        name: 'videoDetail',
        component: () => import('@/teacher/video-class/video-detail'),
        meta: {
          title: '视频课详情'
        }
      },
      {
        path: '/videoClassDetail',
        name: 'videoClassDetail',
        component: () => import('@/teacher/video-class/video-class-detail'),
        meta: {
          title: '视频课详情'
        }
      },
      {
        path: '/liveCreate',
        name: 'liveCreate',
        component: () => import('@/teacher/live-class/create'),
        meta: {
          title: '创建直播课'
        }
      },
      {
        path: '/practiceSetting',
        name: 'practiceSetting',
        component: () => import('@/teacher/practice-class/practice-setting'),
        meta: {
          title: '陪练课设置'
        }
      },
      {
        path: '/myFans',
        name: 'myFans',
        component: () => import('@/teacher/my-fans/index'),
        meta: {
          title: '我的粉丝'
        }
      }
    ]
  },
  ...rootRouter,
  {
    path: '/:pathMatch(.*)*',
    component: () => import('@/views/404'),
    meta: {
      title: '404 Not Fund',
      platform: 'TEACHER'
    }
  }
]
