import { defineComponent, reactive, ref } from 'vue'
import { List } from 'vant'
import request from '@/helpers/request'
import Item from '../list/item'
import { useRoute } from 'vue-router'
import ColResult from '@/components/col-result'

export default defineComponent({
  name: 'MusicList',
  setup() {
    const route = useRoute()
    const params = reactive({
      search: (route.query.search as string) || '',
      musicTagIds: route.query.tagids || '',
      page: 1
    })
    const data = ref<any>(null)
    const loading = ref(false)
    const finished = ref(false)
    const isError = ref(false)

    const FetchList = async () => {
      if (loading.value) {
        return
      }
      loading.value = true
      isError.value = false
      try {
        const res = await request('/api-student/music/sheet/favorite', {
          data: params
        })
        data.value = res.data
        params.page = res.data.pageNo + 1
        finished.value = res.data.pageNo >= res.data.totalPage
      } catch (error) {
        isError.value = true
      }
      loading.value = false
    }

    return () => (
      <List
        loading={loading.value}
        finished={finished.value}
        finished-text={data.value && data.value.rows.length ? '没有更多了' : ''}
        onLoad={FetchList}
        error={isError.value}
      >
        {data.value && data.value.rows.length
          ? data.value.rows.map(item => <Item data={item} />)
          : !loading.value && (
              <ColResult
                tips="暂无收藏曲目"
                classImgSize="SMALL"
                btnStatus={false}
              />
            )}
      </List>
    )
  }
})
