import request from '@/helpers/request'
import { useAsyncState } from '@vueuse/core'
import { defineComponent, reactive, ref, watch } from 'vue'
import { state as appState } from '@/state'
import { Button } from 'vant'
import SelectTagsChild from './select-tags-child'
import styles from './select.module.less'

export default defineComponent({
  name: 'SelectTag',
  props: {
    onComfirm: {
      type: Function,
      default: () => {}
    },
    onCancel: {
      type: Function,
      default: () => {}
    },
    defaultValue: {
      type: String,
      default: ''
    },
    rowSingle: {
      type: Boolean,
      default: false
    },
    needAllButton: {
      type: Boolean,
      default: true
    }
  },
  setup({ onCancel, onComfirm, defaultValue, ...restProps }) {
    const prefix =
      appState.platformType === 'STUDENT' ? '/api-student' : '/api-teacher'
    const { isLoading, state } = useAsyncState(
      request(prefix + '/MusicTag/tree'),
      null
    )
    const resetTags = () => {
      for (const key in tags) {
        if (Object.prototype.hasOwnProperty.call(tags, key)) {
          delete tags[key]
        }
      }
      onCancel()
    }

    const defaultTags = (defaultValue || '').split(',').map(id => Number(id))
    const tags: { [key in string]: number[] } = reactive({})
    const names = {}
    watch(state, () => {
      if (state.value) {
        const list = (state.value && state.value.data) || []
        for (const item of list) {
          const allids = item.children.map(c => {
            names[c.id] = c.name
            return c.id
          })
          tags[item.id] = defaultTags.filter(id => {
            return allids.includes(Number(id))
          })
        }
      }
    })
    return () => {
      const list = (state.value && state.value.data) || []
      return (
        <div class={styles.select}>
          <h4 class={styles.title}>全部标签</h4>
          <div class={styles.content}>
            {list.map(item => {
              if (!item.children || item.children.length <= 0) {
                return null
              }
              return (
                <div class={styles.list} key={item.id}>
                  <div class={styles.tit}>{item.name}</div>
                  <SelectTagsChild
                    key={item.id}
                    // @ts-ignore
                    selected={tags[item.id] || []}
                    child={item.children || []}
                    onSelect={val => {
                      tags[item.id] = val
                    }}
                    {...restProps}
                  />
                </div>
              )
            })}
          </div>
          <footer class="van-safe-area-bottom van-hairline--top">
            <Button class={styles.btn} round onClick={resetTags}>
              重置
            </Button>
            <Button
              class={styles.btn}
              type="primary"
              round
              onClick={() => onComfirm(tags, names)}
            >
              确认
            </Button>
          </footer>
        </div>
      )
    }
  }
})
