import ColHeader from '@/components/col-header'
import ColSearch from '@/components/col-search'
import { Sticky, Image, List } from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'
import VideoItem from './video-item'

import banner from './images/banner.png'
import request from '@/helpers/request'
import ColResult from '@/components/col-result'

export default defineComponent({
  name: 'VideoClass',
  data() {
    return {
      search: '',
      list: [],
      dataShow: true, // 判断是否有数据
      loading: false,
      finished: false,
      params: {
        search: '',
        page: 1,
        rows: 20
      }
    }
  },
  async mounted() {},
  methods: {
    async getList() {
      try {
        let params = this.params
        const res = await request.post('/api-student/videoLesson/selectGroup', {
          data: {
            ...params
          }
        })
        this.loading = false
        const result = res.data || {}
        console.log(result)
        // 处理重复请求数据
        if (this.list.length > 0 && result.pageNo === 1) {
          return
        }
        this.list = this.list.concat(result.rows || [])
        this.finished = result.pageNo >= result.totalPage
        this.params.page = result.pageNo + 1
        this.dataShow = this.list.length > 0
      } catch {
        this.dataShow = false
        this.finished = true
      }
    },
    onSearch(val: string) {
      this.params.search = val
      this.params.page = 1
      this.list = []
      this.dataShow = true // 判断是否有数据
      this.loading = false
      this.finished = false
      this.getList()
    },
    onDetail(item: any) {
      this.$router.push({
        path: '/videoDetail',
        query: {
          groupId: item.id
        }
      })
    }
  },
  render() {
    return (
      <div class={styles.videoClass}>
        <Sticky offsetTop={0}>
          <ColHeader
            class={styles.classHeader}
            border={false}
            background="transparent"
          />
          <ColSearch
            placeholder="请输入老师名称/课程名称"
            onSearch={this.onSearch}
          />
        </Sticky>

        <div class={styles.banner}>
          <Image src={banner} />
        </div>

        <div>
          {this.dataShow ? (
            <List
              class={styles.videoList}
              v-model:loading={this.loading}
              finished={this.finished}
              finishedText="没有更多了"
              onLoad={this.getList}
            >
              {this.list.map(item => (
                <VideoItem item={item} onClick={this.onDetail} />
              ))}
            </List>
          ) : (
            <ColResult btnStatus={false} tips="暂无视频课" />
          )}
        </div>
      </div>
    )
  }
})
