import { postMessage } from '@/helpers/native-message'
import { defineComponent } from 'vue'
import { Button, Image, Sticky, Toast } from 'vant'
import styles from './index.module.less'
import request from '@/helpers/request'
import { state } from '@/state'
import ColResult from '@/components/col-result'
// import ColHeader from "@/components/col-header";

/**
 * 动态引入文件
 * @param fileName 文件名
 * @param path 文件路径
 */
export const getAssetsHomeFile = (fileName: string) => {
  const path = `./images/${fileName}`
  const modules = import.meta.globEager('./images/*')
  return modules[path].default
}

export default defineComponent({
  name: 'music-cert',
  data() {
    return {
      authStatus: null
    }
  },
  mounted() {
    postMessage({ api: 'setBarStatus', content: { status: 0 } })
    // 音乐人审核状态 0、未申请 UNPAALY、已申请 DOING、审核中 PASS、通过 UNPASS、不通过
    let musicianAuthStatus = state.user.data?.musicianAuthStatus
    if (musicianAuthStatus) {
      state.musicCertStatus =
        musicianAuthStatus === 'DOING' || musicianAuthStatus === 'PASS'
          ? true
          : false
    }
    // 如果申请过，则显示标题
    if (state.musicCertStatus) {
      postMessage({ api: 'setBarStatus', content: { status: 1 } })
    }
  },
  unmounted() {
    postMessage({ api: 'setBarStatus', content: { status: 1 } })
  },
  methods: {
    async onClick() {
      try {
        await request.post('/api-teacher/teacherAuthMusicianRecord/doApply', {})
        Toast('申请认证成功')
        state.musicCertStatus = true
        postMessage({ api: 'setBarStatus', content: { status: 1 } })
      } catch {}
    }
  },
  render() {
    return (
      <>
        {state.musicCertStatus ? (
          <ColResult
            classImgSize="CERT"
            type="musicCert"
            style={{ paddingTop: '60px' }}
            tips={
              state.user.data?.musicianAuthStatus === 'PASS'
                ? '您提交的音乐人认证已申请成功'
                : '您已成功提交音乐人认证申请我们将在2个工作日内与您取得联系'
            }
          />
        ) : (
          <div class={styles['music-cert']}>
            <div class={styles.certWrapper}>
              <div class={[styles['cert-section'], 'mb12']}>
                <div class={[styles['cert-text'], styles['cert-tree']]}>
                  <img
                    src={getAssetsHomeFile('tip.png')}
                    class={styles.title}
                  />
                  <div class={styles['cert-desc']}>
                    <p style={{ paddingRight: 0 }}>
                      酷乐秀对有能力编曲的音乐人开通上传曲谱权限，
                    </p>
                    <p>开通后您可上传自己编曲的乐谱MIDI</p>
                    <p>让平台学员进行练习，并获取收益</p>
                  </div>
                </div>

                <div class={[styles['cert-show'], styles['cert-text']]}>
                  <div class={[styles['cert-item']]}>
                    <div class={styles.certLogo}>
                      <Image
                        class={styles.logo}
                        src={getAssetsHomeFile('logo1.png')}
                      />
                    </div>
                    <div class={styles.certInfo}>
                      <div class={styles.certInfoHeader}>
                        <Image
                          class={styles.num}
                          src={getAssetsHomeFile('1.png')}
                        />
                        MP3文件上传
                      </div>
                      <div class={styles.certInfoDesc}>
                        您可上传自己编曲的乐谱MP3，并自定义乐谱价格，为平台学员提供智能陪练练习。
                      </div>
                    </div>
                  </div>

                  <div class={[styles['cert-item']]}>
                    <div class={styles.certLogo}>
                      <Image
                        class={styles.logo}
                        src={getAssetsHomeFile('logo2.png')}
                      />
                    </div>
                    <div class={styles.certInfo}>
                      <div class={styles.certInfoHeader}>
                        <Image
                          class={styles.num}
                          src={getAssetsHomeFile('2.png')}
                        />
                        乐谱收益
                      </div>
                      <div class={styles.certInfoDesc}>
                        您可对上传的乐谱自定义价格，学员可自行挑选乐谱购买，购买后您将获取学员购买收入。
                      </div>
                    </div>
                  </div>
                </div>
              </div>

              <Sticky position="bottom" offsetBottom={0}>
                <div class={styles['btn-group']}>
                  {/* <Button round block type="primary" disabled={this.authStatus === '1'} onClick={this.onClick}>立即认证</Button> */}
                  <div
                    class={[
                      styles.btn,
                      this.authStatus === '1' ? styles.disabled : null
                    ]}
                    onClick={this.onClick}
                  ></div>
                </div>
              </Sticky>
            </div>
          </div>
        )}
      </>
    )
  }
})
