import ColHeader from '@/components/col-header'
import { useEventListener } from '@vant/use'
import { Button, Icon, Image, Sticky } from 'vant'
import { defineComponent, Transition } from 'vue'
import styles from './cert-info.module.less'
import { teacherState } from './teacherState'
/**
 * 动态引入文件
 * @param fileName 文件名
 * @param path 文件路径
 */
export const getAssetsHomeFile = (fileName: string) => {
  const path = `./images/${fileName}`
  const modules = import.meta.globEager('./images/*')
  return modules[path].default
}

export default defineComponent({
  name: 'cert-info',
  // data() {
  //   return {
  //     headStatus: false
  //   }
  // },
  methods: {
    onClick() {
      if (teacherState.authStatus) {
        return
      }
      teacherState.authStatus = true
    }
  },
  render() {
    return (
      <div class={styles['cert-info']}>
        {/* <div class={styles.certContent}> */}
        <ColHeader
          v-slots={{
            content: () => (
              <Sticky position="top" offsetTop={0}></Sticky>
              //   <div class={[styles.certHeader, this.headStatus ? styles.certWhite : null]}>
              //     老师认证
              //   </div>
            )
          }}
        />

        <div class={styles.certContent}></div>

        <div class={styles.certWrapper}>
          <div class={styles['cert-section']}>
            <div class={[styles['cert-text'], styles['cert-tree']]}>
              <img src={getAssetsHomeFile('base.png')} class={styles.title} />
              <div class={styles['cert-desc']}>
                <p>酷乐秀是一款为器乐学习者提供智能陪练及</p>
                <p style={{ paddingRight: 0 }}>线上授课撮合的乐器教学平台，</p>
                <p>器乐老师可通过自身的专业知识为自己带来</p>
                <p style={{ paddingRight: 0, fontWeight: 'bold' }}>
                  授课及曲谱销售收益。
                </p>
              </div>
            </div>

            <div class={[styles['cert-show'], styles['cert-text']]}>
              <div class={[styles['cert-item']]}>
                <div class={styles.certLogo}>
                  <Image
                    class={styles.logo}
                    src={getAssetsHomeFile('logo1.png')}
                  />
                </div>
                <div class={styles.certInfo}>
                  <div class={styles.certInfoHeader}>
                    <Image
                      class={styles.num}
                      src={getAssetsHomeFile('1.png')}
                    />
                    线上授课
                  </div>
                  <div class={styles.certInfoDesc}>
                    认证成为酷乐秀老师后，可设置您的空闲时间为平台中的求学者进行1对1的线上课程指导。
                  </div>
                </div>
              </div>

              <div class={[styles['cert-item']]}>
                <div class={styles.certLogo}>
                  <Image
                    class={styles.logo}
                    src={getAssetsHomeFile('logo2.png')}
                  />
                </div>
                <div class={styles.certInfo}>
                  <div class={styles.certInfoHeader}>
                    <Image
                      class={styles.num}
                      src={getAssetsHomeFile('2.png')}
                    />
                    个人风采展示
                  </div>
                  <div class={styles.certInfoDesc}>
                    可发布自己的专业经历、获奖记录及音视频资料对求学者展示，让学员更加深入的了解您的专业技能，从而提高约课率。
                  </div>
                </div>
              </div>

              <div class={[styles['cert-item']]}>
                <div class={styles.certLogo}>
                  <Image
                    class={styles.logo}
                    src={getAssetsHomeFile('logo3.png')}
                  />
                </div>
                <div class={styles.certInfo}>
                  <div class={styles.certInfoHeader}>
                    <Image
                      class={styles.num}
                      src={getAssetsHomeFile('3.png')}
                    />
                    曲谱上传
                  </div>
                  <div class={styles.certInfoDesc}>
                    可上传您制作的MIDI乐谱为求学者提供学习曲目的途径，并从中获得收益。
                  </div>
                </div>
              </div>

              <div class={[styles['cert-item']]}>
                <div class={styles.certLogo}>
                  <Image
                    class={styles.logo}
                    src={getAssetsHomeFile('logo4.png')}
                  />
                </div>
                <div class={styles.certInfo}>
                  <div class={styles.certInfoHeader}>
                    <Image
                      class={styles.num}
                      src={getAssetsHomeFile('4.png')}
                    />
                    收益提现
                  </div>
                  <div class={styles.certInfoDesc}>
                    在您授课及上传曲谱销售后，经过平台核算，将您获得的收益发放至您的个人账户下，您可随时将自己获得的收益提现。
                  </div>
                </div>
              </div>
            </div>

            <div class={[styles['cert-text'], styles['cert-padding']]}>
              <img src={getAssetsHomeFile('join.png')} class={styles.title} />
              <div class={styles['cert-join']}>
                在艺术的殿堂中，为他人照亮前进的道路，用自己的经验和点拨，传播艺术的种子，获取硕果。
              </div>
            </div>
          </div>

          <Sticky position="bottom" offsetBottom={0}>
            <div class={styles['btn-group']}>
              <div
                class={[
                  styles.btn,
                  teacherState.authStatus ? styles.disabled : null
                ]}
                onClick={this.onClick}
              ></div>
            </div>
          </Sticky>
        </div>
        {/* </div> */}
      </div>
    )
  }
})
