import ColHeader from '@/components/col-header'
import ColResult from '@/components/col-result'
import { Button, Cell, CellGroup, Image, List, Tab, Tabs } from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'

export default defineComponent({
  name: 'shop-order',
  data() {
    return {
      active: '0',
      list: [1],
      dataShow: true, // 判断是否有数据
      loading: false,
      finished: false,
      params: {
        search: '',
        groupStatus: 'APPLY',
        page: 1,
        rows: 20
      }
    }
  },
  methods: {
    getList() {},
    onClickRight() {
      this.$router.push('/afterSale')
    }
  },
  render() {
    return (
      <div class={styles.shopOrder}>
        <ColHeader
          rightText="售后服务"
          onClickRight={this.onClickRight}
          v-slots={{
            default: () => (
              <Tabs
                v-model:active={this.active}
                color="var(--van-primary)"
                lineWidth={28}
              >
                <Tab name="0" title="全部"></Tab>
                <Tab name="1" title="处理中"></Tab>
                <Tab name="2" title="已处理"></Tab>
              </Tabs>
            )
          }}
        />

        {this.dataShow ? (
          <List
            v-model:loading={this.loading}
            finished={this.finished}
            finishedText=" "
            class={[styles.goodsList]}
            onLoad={this.getList}
          >
            {this.list.map((item: any) => (
              <CellGroup class={styles.cellGroup}>
                <Cell
                  title="2022年5月6日20:58:42"
                  titleClass={styles.payTime}
                  value="待支付"
                  valueClass={styles.payStatus}
                ></Cell>
                <Cell
                  center
                  v-slots={{
                    icon: () => (
                      <Image
                        class={styles.goodsImg}
                        src="https://cdn.jsdelivr.net/npm/@vant/assets/cat.jpeg"
                        fit="cover"
                      />
                    ),
                    default: () => (
                      <div class={styles.goodsContainer}>
                        <div class={[styles.goodsTitle, 'van-ellipsis']}>
                          次中音号降调JBBR-1220次中音号降调JBBR-1220次中音号降调JBBR-1220
                        </div>
                        <div class={styles.model}>型号：默认</div>
                        <div class={styles.goodsPrice}>
                          <span class={styles.price}>
                            <i>¥</i>2,5000.0
                          </span>
                          <span class={styles.num}>x1</span>
                        </div>
                      </div>
                    )
                  }}
                ></Cell>
                <Cell
                  center
                  v-slots={{
                    icon: () => (
                      <Image
                        class={styles.goodsImg}
                        src="https://cdn.jsdelivr.net/npm/@vant/assets/cat.jpeg"
                        fit="cover"
                      />
                    ),
                    default: () => (
                      <div class={styles.goodsContainer}>
                        <div class={styles.goodsTitle}>
                          次中音号降调JBBR-1220
                        </div>
                        <div class={styles.model}>型号：默认</div>
                        <div class={styles.goodsPrice}>
                          <span class={styles.price}>
                            <i>¥</i>2,5000.0
                          </span>
                          <span class={styles.num}>x 1</span>
                        </div>
                      </div>
                    )
                  }}
                ></Cell>
                <Cell
                  center
                  v-slots={{
                    title: () => (
                      <div class={styles.orderPrice}>
                        订单金额
                        <span
                          class={styles.price}
                          style={{ paddingLeft: '5px' }}
                        >
                          <i>¥</i>2,5000.0
                        </span>
                      </div>
                    ),
                    default: () => (
                      <div class={styles.btnList}>
                        {/* <span class={styles.sureGoods}>已确认收货</span> */}
                        <Button size="small" round>
                          取消订单
                        </Button>
                        <Button size="small" round type="primary">
                          继续支付
                        </Button>
                      </div>
                    )
                  }}
                ></Cell>
              </CellGroup>
            ))}
          </List>
        ) : (
          <ColResult btnStatus={false} classImgSize="SMALL" tips="暂无订单" />
        )}
      </div>
    )
  }
})
